@@ -1,6 +1,6 @@
 #' Install or Update the Apache Tika \code{jar}
 #'
-#' This downloads and installs the Tika App \code{jar} (~60 MB) into a user directory,
+#' This downloads and installs the Tika App \code{jar} (~55 MB) into a user directory,
 #' and verifies the integrity of the file using a checksum.
 #' The default settings should work fine.
 #'
@@ -13,7 +13,9 @@
 #' @return Logical if the installation was successful.
 #' @examples
 #' \donttest{
-#' install_tika()
+#' if (interactive()) {
+#'   install_tika()
+#' }
 #' }
 #' @section Details:
 #' The default settings of \code{install_tika()} should typically be left as they are.
@@ -53,10 +55,11 @@
 #'
 #' @export
 
-install_tika <- function(version = "2.7.0",
-                         digest = paste0("7fefbe5570a95900d39193134e8277aec99e5450a8",
-                                         "cecbb5787b3d6651ebf735e460ccccddb49bdc2990",
-                                         "8a9058fc36e4689aed6da6d63a1cf70ca09ccf26bcca"),
+install_tika <- function(version = "3.2.3",
+                         digest = paste0(
+                           "5908760c8506d6d1f2c37b59b21b513c2451960b471dde0b353d0ac825a3ea6a",
+                           "809714e0651de9883f8257444b2a8c56c6982a55fed74b5e5840261aa893b650"
+                         ),
                          mirrors = c(
                            "https://ftp.wayne.edu/apache/tika/",
                            "http://mirrors.ocf.berkeley.edu/apache/tika/",
@@ -97,7 +100,7 @@ install_tika <- function(version = "2.7.0",
   message(
     "Downloading the Tika App .jar version ", version, ' into "',
     user_data_dir,
-    '". The file is approximately 60 MB - this may take a while.'
+    '". The file is approximately 55 MB - this may take a while.'
   )
 
   download <- tika_fetch(
